<?php
// Файл: modules/admin_overview.php

// Функция для получения статистики
function getStatistics($period) {
    global $mysqli;
    $end_date = date('Y-m-d H:i:s');
    $start_date = date('Y-m-d H:i:s', strtotime("-1 $period"));

    $query = "SELECT
        (SELECT COUNT(*) FROM users WHERE created_at BETWEEN ? AND ?) as new_users,
        (SELECT COUNT(*) FROM tracks WHERE created_at BETWEEN ? AND ?) as new_tracks,
        (SELECT COUNT(DISTINCT user_id) FROM user_actions WHERE action_time BETWEEN ? AND ?) as active_users";

    $stmt = $mysqli->prepare($query);
    $stmt->bind_param("ssssss", $start_date, $end_date, $start_date, $end_date, $start_date, $end_date);
    $stmt->execute();
    $result = $stmt->get_result()->fetch_assoc();
    $stmt->close();

    return $result;
}

// Получение статистики
$daily_stats = getStatistics('day');
$weekly_stats = getStatistics('week');
$monthly_stats = getStatistics('month');

// Получение данных для графика активности
$activity_query = "SELECT HOUR(action_time) as hour, COUNT(*) as count
                   FROM user_actions
                   WHERE action_time >= DATE_SUB(NOW(), INTERVAL 1 DAY)
                   GROUP BY HOUR(action_time)";
$activity_result = $mysqli->query($activity_query);
$activity_data = [];
while ($row = $activity_result->fetch_assoc()) {
    $activity_data[$row['hour']] = $row['count'];
}

// Заполнение пустых часов нулями
for ($i = 0; $i < 24; $i++) {
    if (!isset($activity_data[$i])) {
        $activity_data[$i] = 0;
    }
}
ksort($activity_data);

// Получение последних действий пользователей
$recent_actions_query = "SELECT u.name, ua.action, ua.action_time
                         FROM user_actions ua
                         JOIN users u ON ua.user_id = u.id
                         ORDER BY ua.action_time DESC
                         LIMIT 10";
$recent_actions_result = $mysqli->query($recent_actions_query);

// Получение важных уведомлений
$notifications_query = "SELECT * FROM admin_notifications
                        WHERE is_read = 0
                        ORDER BY created_at DESC
                        LIMIT 5";
$notifications_result = $mysqli->query($notifications_query);
?>

<div class="container mt-4">
    <h1 class="mb-4">Панель администратора - Обзор</h1>

    <div class="row">
        <div class="col-md-4 mb-4">
            <div class="card">
                <div class="card-header">Статистика за 24 часа</div>
                <div class="card-body">
                    <p>Новые пользователи: <?php echo $daily_stats['new_users']; ?></p>
                    <p>Активные пользователи: <?php echo $daily_stats['active_users']; ?></p>
                    <p>Новые треки: <?php echo $daily_stats['new_tracks']; ?></p>
                </div>
            </div>
        </div>
        <div class="col-md-4 mb-4">
            <div class="card">
                <div class="card-header">Статистика за неделю</div>
                <div class="card-body">
                    <p>Новые пользователи: <?php echo $weekly_stats['new_users']; ?></p>
                    <p>Активные пользователи: <?php echo $weekly_stats['active_users']; ?></p>
                    <p>Новые треки: <?php echo $weekly_stats['new_tracks']; ?></p>
                </div>
            </div>
        </div>
        <div class="col-md-4 mb-4">
            <div class="card">
                <div class="card-header">Статистика за месяц</div>
                <div class="card-body">
                    <p>Новые пользователи: <?php echo $monthly_stats['new_users']; ?></p>
                    <p>Активные пользователи: <?php echo $monthly_stats['active_users']; ?></p>
                    <p>Новые треки: <?php echo $monthly_stats['new_tracks']; ?></p>
                </div>
            </div>
        </div>
    </div>

    <div class="row mb-4">
        <div class="col-12">
            <div class="card">
                <div class="card-header">График активности пользователей за последние 24 часа</div>
                <div class="card-body">
                    <canvas id="activityChart"></canvas>
                </div>
            </div>
        </div>
    </div>

    <div class="row">
        <div class="col-md-8 mb-4">
            <div class="card">
                <div class="card-header">Последние действия пользователей</div>
                <div class="card-body">
                    <ul class="list-group">
                        <?php while ($action = $recent_actions_result->fetch_assoc()): ?>
                            <li class="list-group-item">
                                <?php echo htmlspecialchars($action['name']); ?> -
                                <?php echo htmlspecialchars($action['action']); ?>
                                (<?php echo date('d.m.Y H:i', strtotime($action['action_time'])); ?>)
                            </li>
                        <?php endwhile; ?>
                    </ul>
                </div>
            </div>
        </div>
        <div class="col-md-4 mb-4">
            <div class="card">
                <div class="card-header">Важные уведомления</div>
                <div class="card-body">
                    <?php if ($notifications_result->num_rows > 0): ?>
                        <ul class="list-group">
                            <?php while ($notification = $notifications_result->fetch_assoc()): ?>
                                <li class="list-group-item">
                                    <?php echo htmlspecialchars($notification['message']); ?>
                                    <small class="text-muted d-block">
                                        <?php echo date('d.m.Y H:i', strtotime($notification['created_at'])); ?>
                                    </small>
                                </li>
                            <?php endwhile; ?>
                        </ul>
                    <?php else: ?>
                        <p>Нет новых уведомлений</p>
                    <?php endif; ?>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
    // Создание графика активности
    var ctx = document.getElementById('activityChart').getContext('2d');
    var activityChart = new Chart(ctx, {
        type: 'line',
        data: {
            labels: <?php echo json_encode(array_keys($activity_data)); ?>,
            datasets: [{
                label: 'Активность пользователей',
                data: <?php echo json_encode(array_values($activity_data)); ?>,
                borderColor: 'rgb(75, 192, 192)',
                tension: 0.1
            }]
        },
        options: {
            responsive: true,
            scales: {
                y: {
                    beginAtZero: true
                }
            }
        }
    });
</script>
